==> haskell-lucid-2.11.20230408-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lucid
version:              2.11.20230408
visibility:           public
id:                   lucid-2.11.20230408-49csFFjuei4DgCdIhV8tqI
key:                  lucid-2.11.20230408-49csFFjuei4DgCdIhV8tqI
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  7c11e7a3212076710ffb9b1ab6f5ab92
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lucid-2.11.20230408
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lucid-2.11.20230408
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20230408-49csFFjuei4DgCdIhV8tqI
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.11.20230408-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lucid
version:              2.11.20230408
visibility:           public
id:                   lucid-2.11.20230408-8TFUdOQcdTu4zmMpv3UMa6
key:                  lucid-2.11.20230408-8TFUdOQcdTu4zmMpv3UMa6
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  16b45c98cfc45df4a3221cfa0033b0d9
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lucid-2.11.20230408
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lucid-2.11.20230408
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20230408-8TFUdOQcdTu4zmMpv3UMa6
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
